AppwriteColors class

Constructors

AppwriteColors.init(BuildContext context)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

background → Color
no setter
text → Color
no setter
textFieldBackground → Color
no setter
textFieldBorder → Color
no setter

Constants

danger → const Color
notice → const Color
primary → const Color
success → const Color
warning → const Color