AppwriteService class

Constructors

AppwriteService()
factory

Properties

account → Future<Account>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

logout() → Future<void>
Logs out the user Deletes the session from the Appwrite server Deletes the session from local storage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isInitialized → bool
no setter
isLoggedIn → bool
no setter

Static Methods

createEmailAccount({required String email, required String password, String? name}) → Future<Map<String, dynamic>>
Returns a map with the following keys: if there was no error:
createPhoneAccount({required String phone, bool connectMode = false}) → Future<Map<String, dynamic>>
Returns a map with the following keys: if there was no error:
init({required String endpoint, required String projectId, String? recovery, bool selfSigned = true}) → Future<void>
Initializes the Appwrite service endpoint is the endpoint from the Appwrite console projectId is the project ID from the Appwrite console selfSigned is used to set the self signed certificate - default is true
loginEmailAccount({required String email, required String password}) → Future<Map<String, dynamic>>
Returns a map with the following keys: if there was no error:
resetEmailPassword({required String email}) → Future<Map<String, dynamic>>
Returns a map with the following keys: if there was no error:
resetPassword({required String userId, required String secret, required String password, required String passwordAgain}) → Future<Map<String, dynamic>>
Returns a map with the following keys: if there was no error:
updatePhoneSession({required String userId, required String secret}) → Future<Map<String, dynamic>>
Returns a map with the following keys: if there was no error: